<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="175"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Kliknij aby zmienić kolor.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Wybierz kolor</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Następne (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Poprzednie (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Szukaj…</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Szukaj tylko w nazwach (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Szukaj tylko w tagach (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Szukaj we wszystkich węzłach (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Pełny wyraz (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Pełny wyraz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Dopasuj (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Dopasuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>Ostatnio o&amp;twierane</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edytuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>For&amp;matowanie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Drzewo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>&amp;Opcje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Szukaj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Szukaj:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Zastąp z:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Do zastąpienia</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Tekst zastępujący</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Poprzednie (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Następne (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Zastąp wszystkie (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>Zapi&amp;sz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1031"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;Open</source>
        <translation>&amp;Otwórz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Cofnij</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>Powtó&amp;rz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Powtórz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Szukaj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Pokaż/ukryj pasek wyszukiwania</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>Wy&amp;czyść całe formatowanie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Wyczyść całe formatowanie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>Pogru&amp;bienie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>Pochylen&amp;ie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Pochylenie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>&amp;Podkreślenie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>P&amp;rzekreślenie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Przekreślenie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>&amp;Kolor tekstu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Kolor tekstu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>Ko&amp;lor tła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Kolor tła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Shift+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="690"/>
        <source>&amp;New Note</source>
        <translation>&amp;Nowa notatka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Z&amp;apisz jako</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>Wy&amp;drukuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>Wydrukuj z węzłami pochodnymi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>Usta&amp;w hasło</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="693"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>&amp;Wytnij</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>K&amp;opiuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>W&amp;klej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>Zaznacz wszy&amp;stko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>&amp;Osadź obraz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4378"/>
        <source>Embed Image</source>
        <translation>Osadź obraz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>Rozwiń &amp;wszystko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>Zwiń wszy&amp;stko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>Umieść bliźni&amp;aka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>Umieść dzie&amp;cko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Usuń węzeł</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>Przenieś w &amp;górę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>Przenieś &amp;w dół</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>Zmień &amp;nazwę węzła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>Właściw&amp;ości drzewa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>&amp;Czcionka dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>Zawijaj &amp;wiersze</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Automatyczne wcięcia</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferencje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>&amp;Znajdź i zastąp</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>O progr&amp;amie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>Wydrukuj wszystk&amp;ie węzły</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>Indeks &amp;górny</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Indeks górny</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>Indeks &amp;dolny</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Indeks dolny</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>&amp;Wyśrodkuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Wyrównaj do środka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2176"/>
        <source>&amp;Right</source>
        <translation>Wyrównaj do p&amp;rawej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Wyrównaj do prawej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2170"/>
        <source>&amp;Left</source>
        <translation>Wyrównaj do &amp;lewej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Wyrównaj do lewej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+W lewo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>Wy&amp;justuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Wyjustuj</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Poprzedź bliźniakiem</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>Przenieś w &amp;lewo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+W lewo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>Przenieś w p&amp;rawo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>h&amp;2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Nagłówek 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>h&amp;1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Nagłówek 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>h&amp;3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Nagłówek 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>Czcio&amp;nka węzła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Czcionka węzła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>&amp;Skaluj obraz(y)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>Wklej &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>&amp;Tagi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Umieść odnośni&amp;k</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>Sk&amp;opiuj odnośnik</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>&amp;Umieść tabelę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Umieść rząd</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Usuń rząd</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Umieść kolumnę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Usuń kolumnę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Połącz komórki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Poprzedź rzędem</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Poprzedź kolumną</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Eksportuj &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>&amp;Zapisz obraz(y)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Od prawej do lewej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+W lewo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Od lewej do prawej</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+W prawo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>&amp;Ikona węzła</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>Kolory &amp;dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Wklej datę i czas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>Wy&amp;czyść</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2963"/>
        <source>Node Icon</source>
        <translation>Ikona węzła</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="675"/>
        <source>&amp;Raise/Hide</source>
        <translation>Wznieś/Uk&amp;ryj</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="927"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nowa notatka?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Czy na pewno chcesz zamknąć ten dokument&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;i utworzyć nowy?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="931"/>
        <location filename="../../fn.cpp" line="2794"/>
        <location filename="../../fn.cpp" line="4741"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2795"/>
        <location filename="../../fn.cpp" line="4742"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1023"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Zapisać zmiany?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1025"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Ten dokument został zmodyfikowany.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1027"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Ten dokument został usunięty.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Discard changes</source>
        <translation>Odrzuć zmiany</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <location filename="../../fn.cpp" line="2912"/>
        <location filename="../../fn.cpp" line="3006"/>
        <location filename="../../fn.cpp" line="3279"/>
        <location filename="../../fn.cpp" line="4317"/>
        <location filename="../../fn.cpp" line="4402"/>
        <location filename="../../fn.cpp" line="4580"/>
        <location filename="../../fn.cpp" line="4843"/>
        <location filename="../../fn.cpp" line="5796"/>
        <location filename="../../fn.cpp" line="6075"/>
        <location filename="../../fn.cpp" line="6173"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1443"/>
        <source>Open file...</source>
        <translation>Otwórz plik…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1620"/>
        <location filename="../../fn.cpp" line="5922"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nie można zapisać!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3575"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1720"/>
        <location filename="../../fn.cpp" line="1743"/>
        <source>Save As...</source>
        <translation>Zapisz jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <source>FeatherNotes documents</source>
        <translation>Dokumenty FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>All Files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2791"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Usunąć ten węzeł?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2792"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Ostrzeżenie!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Nie możesz tego cofnąć.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2898"/>
        <source>Tags</source>
        <translation>Tagi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2913"/>
        <location filename="../../fn.cpp" line="3007"/>
        <location filename="../../fn.cpp" line="3280"/>
        <location filename="../../fn.cpp" line="4319"/>
        <location filename="../../fn.cpp" line="4403"/>
        <location filename="../../fn.cpp" line="4581"/>
        <location filename="../../fn.cpp" line="4844"/>
        <location filename="../../fn.cpp" line="5798"/>
        <location filename="../../fn.cpp" line="6076"/>
        <location filename="../../fn.cpp" line="6174"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Image Files</source>
        <translation>Pliki obrazów</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3087"/>
        <location filename="../../fn.cpp" line="3120"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Główne węzły:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Wszystkie węzły:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3093"/>
        <location filename="../../fn.cpp" line="3126"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Notatka:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Główne węzły:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Wszystkie węzły:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3562"/>
        <source>%1 Matches</source>
        <translation>%1 wystąpienia</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3564"/>
        <source>One Match</source>
        <translation>Jedno wystąpienie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3566"/>
        <location filename="../../fn.cpp" line="3933"/>
        <source>No Match</source>
        <translation>Brak wystąpień</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3732"/>
        <location filename="../../fn.cpp" line="3785"/>
        <source>Replacement</source>
        <translation>Zastąpienie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4040"/>
        <source>No Replacement</source>
        <translation>Bez zamiennika</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4042"/>
        <source>One Replacement</source>
        <translation>Jeden zamiennik</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4045"/>
        <source>%1 Replacements</source>
        <translation>%1 zamienniki</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4305"/>
        <source>Insert Link</source>
        <translation>Wstaw odnośnik</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6019"/>
        <source>HTML Files</source>
        <translation>Pliki HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="4387"/>
        <source>Image path</source>
        <translation>Ścieżka obrazu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2975"/>
        <location filename="../../fn.cpp" line="4391"/>
        <source>Open image</source>
        <translation>Otwórz obraz</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4399"/>
        <location filename="../../fn.cpp" line="4577"/>
        <source>Scaling percentage</source>
        <translation>Skalowanie procentowo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2993"/>
        <location filename="../../fn.cpp" line="4499"/>
        <source>Open Image...</source>
        <translation>Otwórz obraz…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="652"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Tacka systemowa nie jest dostępna.
Proszę wyłączyć tackę w Preferencjach.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="978"/>
        <source>New Node</source>
        <translation>Nowa gałąź</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1621"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nie można otworzyć!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1702"/>
        <location filename="../../fn.cpp" line="5637"/>
        <location filename="../../fn.cpp" line="5646"/>
        <location filename="../../fn.cpp" line="5785"/>
        <location filename="../../fn.cpp" line="5976"/>
        <location filename="../../fn.cpp" line="5985"/>
        <location filename="../../fn.cpp" line="6012"/>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2169"/>
        <source>Align Table</source>
        <translation>Wyrównaj tabelę</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2182"/>
        <source>&amp;Center</source>
        <translation>Wyśro&amp;dkuj</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2621"/>
        <source>Select Text Color</source>
        <translation>Wybierz kolor tekstu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2653"/>
        <source>Select Background Color</source>
        <translation>Wybierz kolor tła</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2790"/>
        <source>Deletion</source>
        <translation>Usuwanie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2908"/>
        <source>Tag(s) for this node</source>
        <translation>Tag(i) dla tego węzła</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3164"/>
        <source>Select Document Font</source>
        <translation>Wybierz czcionkę dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3226"/>
        <source>Select Node Font</source>
        <translation>Wybierz czcionkę węzła</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3251"/>
        <source>Set Document Colors</source>
        <translation>Ustaw kolory dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3261"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Te kolory zostaną zastosowane do nowych węzłów.&lt;br&gt;Mogą mieć wpływ na istniejące węzły lub nie,&lt;br&gt;ale zalecane jest ponowne otwarcie dokumentu.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Background color:</source>
        <translation>Kolor tła:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3270"/>
        <source>Text color:</source>
        <translation>Kolor tekstu:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4050"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>Wyróżniono pierwszych 1000 zamienników.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4394"/>
        <location filename="../../fn.cpp" line="4573"/>
        <source>Scale to</source>
        <translation>Skaluj do</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4398"/>
        <location filename="../../fn.cpp" line="4576"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4567"/>
        <source>Scale Image(s)</source>
        <translation>Skaluj obraz(y)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4704"/>
        <source>untitled</source>
        <translation>bez tytułu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4736"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4737"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nie udało się zapisać obrazu! Spróbować ponownie?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4738"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Może wybrałeś złe rozszerzenie&lt;/center&gt;
&lt;center&gt;lub nie masz uprawnień do zapisu?&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4770"/>
        <source>Save Image As...</source>
        <translation>Zapisz obraz jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4825"/>
        <source>Insert Table</source>
        <translation>Wstaw tabelę</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4831"/>
        <source>Rows:</source>
        <translation>Rzędy:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4837"/>
        <source>Columns:</source>
        <translation>Kolumny:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5726"/>
        <source>Print Document</source>
        <translation>Wydrukuj dokument</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5732"/>
        <source>Printing completed.</source>
        <translation>Drukowanie zakończone.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5734"/>
        <source>Printing in progress...</source>
        <translation>Trwa drukowanie...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5753"/>
        <source>Export HTML</source>
        <translation>Eksportuj HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5758"/>
        <source>Export:</source>
        <translation>Eksportuj:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5759"/>
        <source>&amp;Current node</source>
        <translation>Obe&amp;cny węzeł</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5761"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Ze w&amp;szystkimi węzłami pochodnymi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5762"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Wszystkie węzły</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5774"/>
        <source>Output file:</source>
        <translation>Plik wyjściowy:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>Select path</source>
        <translation>Wybierz ścieżkę</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5834"/>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5835"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Plik już istnieje.
Czy chcesz go zamienić?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6017"/>
        <source>Save HTML As...</source>
        <translation>Zapisz HTML jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Set Password</source>
        <translation>Ustaw hasło</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6052"/>
        <source>Type password</source>
        <translation>Wprowadź hasło</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6064"/>
        <source>Retype password</source>
        <translation>Wprowadź hasło ponownie</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6136"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Hasła nie pasują do siebie. Spróbuj ponownie!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6156"/>
        <location filename="../../fn.cpp" line="6164"/>
        <source>Enter Password</source>
        <translation>Wprowadź hasło</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6236"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Nieprawidłowe hasło. Spróbuj ponownie!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6275"/>
        <source>A lightweight notes manager</source>
        <translation>Lekki menedżer notatek</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6276"/>
        <source>based on Qt</source>
        <translation>oparty o Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6277"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <location filename="../../fn.cpp" line="6280"/>
        <source>About FeatherNotes</source>
        <translation>O FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <source>Translators</source>
        <translation>Tłumacze</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6463"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Zobacz Preferencje → Tekst → Sprawdzanie pisowni!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6479"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Musisz dodać słownik Hunspell.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6484"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Słownik Hunspell nie istnieje.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6492"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Słownikowi Hunspell nie towarzyszy plik afiksowy.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6510"/>
        <location filename="../../fn.cpp" line="6525"/>
        <location filename="../../fn.cpp" line="6537"/>
        <source>No misspelling from text cursor.</source>
        <translation>Brak błędów ortograficznych z kursora tekstowego.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6549"/>
        <source>Spell Checking</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6278"/>
        <source>aka.</source>
        <translation>aka.</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Wyczyść tekst (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Zapisuje rozmiar okna po zamknięciu
tego okna i przy wyjściu.

Odznacz, aby pozostawić stały rozmiar!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>&amp;Zapamiętaj rozmiar okna</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Rozpocznij z tym rozmiarem: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Zapisuje szerokość drzewa po zamknięciu
tego okna dialogowego, a także przy wyjściu.

Odznacz dla współczynnika szerokości 170/530.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Zapamię&amp;taj szerokość drzewa</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Zapisuje pozycję po zamknięciu tego
okna dialogowego, a także przy wyjściu.

To może nie działać poprawnie
z niektórymi menedżerami okien.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Zapisz &amp;położenie</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Decyduje, czy ma być używana ikona na pasku zadań.
Jeśli zaznaczono, przycisk zamykania paska tytułowego
zamiast zamykania wyświetla ikonę okna na pasku zadań.

Wymaga ponownego uruchomienia programu FeatherNotes,
aby zaczęło obowiązywać.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Dodaj do zasobnika s&amp;ystemu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Zamiast tego możesz skorzystać
z opcji wiersza poleceń --tray.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Uru&amp;chamiaj jako ikona w zasobniku</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Połączyć widok drzewa z jego otoczeniem?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Przejrzysty wi&amp;dok drzewa</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Domyślnie aktywny styl widżetu określa rozmiar
ikon paska narzędzi.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Małe ikony paska narzędzi</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Nie p&amp;okazuj paska narzędzi</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Jeżeli pasek menu jest ukryty, przycisk menu pojawi się na pasku zadań.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Nie pokazuj paska &amp;menu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>Domyślnie za&amp;wijaj wiersze</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>Domyśln&amp;ie twórz automatyczne wcięcia</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Obejmuje to nawiasy, nawiasy klamrowe i cudzysłowy.

Musisz uruchomić ponownie FeatherNotes, aby uzyskać efekt.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>Automatyczne &amp;nawiasy</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Potrójna kropka jest zastępowana wielokropkiem,
podwójny myślnik długą kreską itp. Podczas pisania
przez użytkownika i w odpowiednich okolicznościach.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>&amp;Zastąp niektóre znaki podczas pisania</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Służy do wklejania daty i godziny.
Pozostaw puste dla wartości domyślnej systemu.

Zaczyna obowiązywać po zamknięciu tego okna
dialogowego.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Format daty i godziny:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Automatycznie zapisuj co</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> minut(y)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Jeśli ta opcja jest zaznaczona, otwarty dokument zostanie
zapisany przy wyjściu bez monitu i bez wyświetlenia ostrzeżenia,
jeśli zapisanie nie jest możliwe.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Zapisz otwarty dokument przy wychodzeniu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Słownik Hunspell ma nazwę kończącą się na „.dic”
i powinien znajdować się obok pliku przyrostka o tej
samej nazwie, ale kończącego się na „.aff”.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Ścieżka słownika Hunspell:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>Dodaj słownik...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Zacznij od ostatnio otwartego pliku</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Liczba ostatnich plików:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Otwórz ostatnie pliki osobno</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Domyślnie wszystkie węzły są rozwijane podczas otwierania dokumentu.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Zapamiętaj rozszerzone stany węzłów</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Działanie</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Ostrzeżenie: Wykryto niejednoznaczny skrót!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Wprowadzony skrót został zarejestrowany.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Konieczne jest ponowne uruchomienie programu, aby zmiany zaczęły obowiązywać.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Pliki słownika Hunspell</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Nieznane słowo:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Dodaj do katalogu</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Zastąp na:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Zignoruj raz</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Ignoruj wszystkie</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Popraw raz</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Popraw wszystko</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>Nowy węzeł</translation>
    </message>
</context>
</TS>
